@@ -1,6 +1,8 @@
 package uk.ac.starlink.table;
 
 import java.io.BufferedOutputStream;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -28,7 +30,6 @@ import uk.ac.starlink.fits.AbstractWideFits;
 import uk.ac.starlink.fits.BintableStarTable;
 import uk.ac.starlink.fits.ColFitsTableWriter;
 import uk.ac.starlink.fits.ColFitsTableBuilder;
-import uk.ac.starlink.fits.FitsConstants;
 import uk.ac.starlink.fits.FitsTableBuilder;
 import uk.ac.starlink.fits.FitsTableWriter;
 import uk.ac.starlink.fits.HealpixFitsTableWriter;
@@ -101,8 +102,6 @@ public class FormatsTest extends TableCase {
         Logger.getLogger( "uk.ac.starlink.feather" ).setLevel( Level.SEVERE );
         Logger.getLogger( "uk.ac.starlink.ecsv" ).setLevel( Level.SEVERE );
         Logger.getLogger( "uk.ac.starlink.parquet" ).setLevel( Level.WARNING );
-
-        FitsConstants.configureHierarch();
     }
 
     private StarTable table;
@@ -369,6 +368,26 @@ public class FormatsTest extends TableCase {
               VOTableVersion.getKnownVersions().values() ) {
             exerciseVOTableVersion( vers );
         }
+
+        StarTableOutput sto = new StarTableOutput();
+        StarTableFactory tfact = new StarTableFactory( false );
+        StarTable t1 = table;
+        for ( String config :
+              new String[] {
+                  "format=TABLEDATA,compact=false",
+                  "format=TABLEDATA,compact=true",
+                  "format=BINARY2,encoding=UTF-16",
+              } ) {
+            VOTableWriter writer =
+                (VOTableWriter) sto.getHandler( "votable(" + config + ")" );
+            ByteArrayOutputStream bout = new ByteArrayOutputStream();
+            writer.writeStarTable( t1, bout );
+            StarTable t2 =
+                tfact
+               .makeStarTable( new ByteArrayInputStream( bout.toByteArray() ),
+                               new VOTableBuilder() );
+            assertVOTableEquals( t1, t2, false );
+        }
     }
 
     public void exerciseVOTableVersion( VOTableVersion vers )
